import { IToolCallPayload, IToolExecutionResult, IToolInstructions, SimplifiedSchemaMatchResult, ToolCallType } from '../../types';
import { IAgentGraphItemSchema } from '../../types/agents';
import { Configuration } from '../Configuration';
import { GraphItem } from '../graphs';
import { ToolCall, ToolCallResult } from './ToolCall';
/**
 * Creates a tool representation for xpanderAI based on tool instructions,
 * formatting description and ensuring parameter fields are included.
 *
 * @param toolInstructions - Instructions containing details about the tool.
 * @returns A tool object structured for use in xpanderAI.
 */
export declare function createTool(toolInstructions: IToolInstructions): any;
/**
 * Executes a specified tool for an agent in xpanderAI, sending a request with
 * the appropriate payload structure including headers, path, query, and body parameters.
 *
 * @param tool - The tool call details.
 * @param agentUrl - The base URL of the agent.
 * @param configuration - Configuration for authentication and custom params.
 * @param sourceNodeType - Source node type for tool operation.
 * @returns The result of the tool execution, parsed as JSON if possible.
 * @throws Error if the response status code indicates failure.
 */
export declare function executeTool(tool: ToolCall, agentUrl: string, configuration: Configuration, executionId: string, isMultiple?: boolean): IToolExecutionResult;
export declare function testToolGraphPosition(tool: ToolCall, agentUrl: string, configuration: Configuration, executionId: string): boolean;
/**
 * Generates the base signature for a tool, identifying tool type.
 *
 * @param toolName - The name of the tool.
 * @param toolCallId - Unique identifier for the tool call.
 * @returns An object containing base details about the tool, such as its type and ID.
 */
export declare function getToolBaseSignature(toolName: string, toolCallId: string): {
    name: string;
    type: ToolCallType;
    toolCallId: string;
};
/**
 * Performs a deep merge of two objects, combining arrays and overriding properties.
 *
 * @param target - The target object to merge into.
 * @param source - The source object to merge from.
 * @returns A new object representing the merged result.
 */
export declare function mergeDeep<T>(target: T, source: T): T;
/**
 * Ensures a consistent structure for the tool call payload, setting default values for parameters.
 *
 * @param payload - The payload object to structure.
 * @returns A structured tool call payload.
 */
export declare function ensureToolCallPayloadStructure(isLocal: boolean | undefined, payload: any): IToolCallPayload;
/**
 * Extracts properties from a schema object, simplifying it into a list of match results
 * containing paths, blocked statuses, and permanent values.
 *
 * @param obj - The schema object to extract properties from.
 * @param path - The current traversal path (used internally).
 * @returns A list of simplified schema match results.
 */
export declare function extractSimplifiedSchemaProps(obj: any, path?: string[]): SimplifiedSchemaMatchResult[];
/**
 * Deletes a property from an object or array by following a specified path.
 *
 * @param obj - The object from which to delete the property.
 * @param path - The dot-separated path to the property.
 */
export declare function deletePropertyByPath(obj: any, path: string): void;
/**
 * Filters out properties from a tool's parameters based on schema restrictions, such as
 * blocked properties or those with permanent values.
 *
 * @param tool - The tool object to filter.
 * @param schemasByNodeName - The schemas defining property restrictions.
 * @param kind - The type of schema to consider ('input' or 'output').
 */
export declare function modifyPropertiesByRemoteSettings(tool: any, kind: 'input' | 'output', graphItem?: GraphItem): any;
/**
 * Sets a value in an object or array at a specified path, creating intermediate objects as needed.
 *
 * @param obj - The target object or array.
 * @param path - The dot-separated path where the value should be set.
 * @param value - The value to set.
 */
export declare function setValueByPath<T extends object>(obj: T, path: string, value: any): void;
/**
 * Appends permanent values to the tool's payload based on schema restrictions.
 *
 * @param tool - The tool object to modify.
 * @param schemasByNodeName - The schemas defining property restrictions.
 */
export declare function appendPermanentValues(tool: ToolCall, schemas: IAgentGraphItemSchema): ToolCall;
/**
 * Appends permanent values to the tool call result based on schema restrictions.
 *
 * @param toolCallResult - The tool call result to modify.
 * @param schemasByNodeName - The schemas defining property restrictions.
 */
export declare function appendPermanentValuesToResult(toolCallResult: ToolCallResult, schemas: IAgentGraphItemSchema): ToolCallResult;
/**
 * Appends description override values to the tool's parameters description based on schema restrictions.
 *
 * @param tool - The tool object to modify.
 * @param schemasByNodeName - The schemas defining property restrictions.
 */
export declare function appendDescriptionOverride(tool: any, graphItem: GraphItem): any;
